@@ -1,7 +1,8 @@
 /*
-    $Id: util.h,v 1.2 2003/11/18 03:35:19 rocky Exp $
+    $Id: util.h,v 1.5 2004/11/15 19:41:25 nboullis Exp $
 
     Copyright (C) 2000 Herbert Valerio Riedel <hvr@gnu.org>
+    Copyright (C) 2004 Rocky Bernstein <rocky@panix.com>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -71,6 +72,16 @@ _cdio_ofs_add (unsigned offset, unsigned length, int blocksize)
   return offset;
 }
 
+static inline const char *
+_cdio_bool_str (bool b)
+{
+  return b ? "yes" : "no";
+}
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void *
 _cdio_malloc (size_t size);
 
@@ -92,16 +103,26 @@ _cdio_strlenv(char **str_array);
 char **
 _cdio_strsplit(const char str[], char delim);
 
-static inline const char *
-_cdio_bool_str (bool b)
-{
-  return b ? "yes" : "no";
+uint8_t cdio_to_bcd8(uint8_t n);
+uint8_t cdio_from_bcd8(uint8_t p);
+
+#if defined(__GNUC__) && __GNUC__ >= 3
+static inline __attribute__((deprecated))
+uint8_t to_bcd8(uint8_t n) {
+  return cdio_to_bcd8(n);
 }
+static inline __attribute__((deprecated))
+uint8_t from_bcd8(uint8_t p) {
+  return cdio_from_bcd8(p);
+}
+#else
+#define to_bcd8 cdio_to_bcd8
+#define from_bcd8 cdio_from_bcd8
+#endif
 
-/* BCD */
-
-uint8_t  to_bcd8(uint8_t n);
-uint8_t  from_bcd8(uint8_t p);
+#ifdef __cplusplus
+}
+#endif
 
 #endif /* __CDIO_UTIL_H__ */
 
