@@ -1,7 +1,7 @@
 /*
-  $Id: cd-drive.c,v 1.11 2004/11/14 00:03:52 rocky Exp $
+  $Id: cd-drive.c,v 1.17 2005/01/22 22:21:36 rocky Exp $
 
-  Copyright (C) 2004 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2004, 2005 Rocky Bernstein <rocky@panix.com>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,15 +22,9 @@
 
 #include "util.h"
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
 #ifdef HAVE_STDIO_H
 #include <stdio.h>
 #endif
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -86,14 +80,14 @@ parse_options (int argc, const char *argv[])
     switch (opt) {
       
     case OP_SOURCE_DEVICE: 
-      if (opts.source_image != IMAGE_UNKNOWN) {
+      if (opts.source_image != DRIVER_UNKNOWN) {
 	report( stderr, "%s: another source type option given before.\n", 
 		program_name );
 	report( stderr, "%s: give only one source type option.\n", 
 		program_name );
 	break;
       } else {
-	opts.source_image  = IMAGE_DEVICE;
+	opts.source_image  = DRIVER_DEVICE;
 	source_name = fillout_device_name(source_name);
 	break;
       }
@@ -107,7 +101,7 @@ parse_options (int argc, const char *argv[])
   {
     const char *remaining_arg = poptGetArg(optCon);
     if ( remaining_arg != NULL) {
-      if (opts.source_image != IMAGE_UNKNOWN) {
+      if (opts.source_image != DRIVER_UNKNOWN) {
 	report( stderr, "%s: Source specified in option %s and as %s\n", 
 		program_name, source_name, remaining_arg);
 	poptFreeContext(optCon);
@@ -115,7 +109,7 @@ parse_options (int argc, const char *argv[])
 	exit (EXIT_FAILURE);
       }
       
-      if (opts.source_image == IMAGE_DEVICE)
+      if (opts.source_image == DRIVER_DEVICE)
 	source_name = fillout_device_name(remaining_arg);
       else 
 	source_name = strdup(remaining_arg);
@@ -163,13 +157,13 @@ init(void)
   /* Default option values. */
   opts.silent        = false;
   opts.debug_level   = 0;
-  opts.source_image  = IMAGE_UNKNOWN;
+  opts.source_image  = DRIVER_UNKNOWN;
 }
 
 int
 main(int argc, const char *argv[])
 {
-  CdIo *p_cdio=NULL;
+  CdIo_t *p_cdio=NULL;
   
   init();
 
@@ -177,7 +171,7 @@ main(int argc, const char *argv[])
      be reflected in `arguments'. */
   parse_options(argc, argv);
      
-  print_version(program_name, VERSION, false, opts.version_only);
+  print_version(program_name, CDIO_VERSION, false, opts.version_only);
 
   if (opts.debug_level == 3) {
     cdio_loglevel_default = CDIO_LOG_INFO;
@@ -188,9 +182,11 @@ main(int argc, const char *argv[])
   if (NULL == source_name) {
     char *default_device;
 
-    p_cdio = cdio_open (NULL, DRIVER_UNKNOWN);
+    p_cdio = cdio_open (NULL, DRIVER_DEVICE);
 
-    if (NULL != p_cdio) {
+    if (NULL == p_cdio) {
+      printf("No loaded CD-ROM device accessible.\n");
+    }  else {
       default_device = cdio_get_default_device(p_cdio);
       
       printf("The driver selected is %s\n", cdio_get_driver_name(p_cdio));
@@ -212,10 +208,10 @@ main(int argc, const char *argv[])
 
     printf("Drivers available...\n");
     for (driver_id=CDIO_MIN_DRIVER; driver_id<=CDIO_MAX_DRIVER; driver_id++)
-      printf("  %-35s: %s\n", 
-	     cdio_driver_describe(driver_id),
-	     cdio_have_driver(driver_id) ? "Yes" : "No");
-    printf("\n\n");
+      if (cdio_have_driver(driver_id)) {
+	printf("  %-35s\n", cdio_driver_describe(driver_id));
+      }
+    printf("\n");
   }
   
     
@@ -232,7 +228,7 @@ main(int argc, const char *argv[])
 	cdio_drive_write_cap_t i_write_cap;
 	cdio_drive_misc_cap_t  i_misc_cap;
 	cdio_hwinfo_t          hwinfo;
-	CdIo *p_cdio = cdio_open(*ppsz_cd, driver_id); 
+	CdIo_t *p_cdio = cdio_open(*ppsz_cd, driver_id); 
 
 	printf("%28s: %s\n", "Drive", *ppsz_cd);
 
