@@ -1,7 +1,7 @@
 /*
-  $Id: util.c,v 1.27 2004/11/06 09:16:04 rocky Exp $
+  $Id: util.c,v 1.31 2005/01/09 16:33:18 rocky Exp $
 
-  Copyright (C) 2003, 2004 Rocky Bernstein <rocky@panix.com>
+  Copyright (C) 2003, 2004, 2005 Rocky Bernstein <rocky@panix.com>
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ char *source_name = NULL;
 char *program_name;
 
 void 
-myexit(CdIo *cdio, int rc) 
+myexit(CdIo_t *cdio, int rc) 
 {
   if (NULL != cdio) cdio_destroy(cdio);
   if (NULL != program_name) free(program_name);
@@ -44,7 +44,8 @@ print_version (char *program_name, const char *version,
   driver_id_t driver_id;
 
   if (no_header == 0)
-    report( stdout,  "%s version %s\nCopyright (c) 2003, 2004 R. Bernstein\n",
+    report( stdout,  
+	    "%s version %s\nCopyright (c) 2003, 2004, 2005 R. Bernstein\n",
 	    program_name, version);
   report( stdout,  
 	  _("This is free software; see the source for copying conditions.\n\
@@ -70,6 +71,87 @@ PARTICULAR PURPOSE.\n\
   
 }
 
+/*! Device input routine. If successful we return an open CdIo_t
+    pointer. On error the program exits.
+ */
+CdIo_t *
+open_input(const char *psz_source, source_image_t source_image,
+	   const char *psz_access_mode)
+{
+  CdIo_t *p_cdio = NULL;
+  switch (source_image) {
+  case INPUT_UNKNOWN:
+  case INPUT_AUTO:
+    p_cdio = cdio_open_am (psz_source, DRIVER_UNKNOWN, psz_access_mode);
+    if (!p_cdio) {
+      if (psz_source) {
+	err_exit("Error in automatically selecting driver for input %s.\n", 
+		 psz_source);
+      } else {
+	err_exit("%s", "Error in automatically selecting driver.\n");
+      }
+    } 
+    break;
+  case INPUT_DEVICE:
+    p_cdio = cdio_open_am (psz_source, DRIVER_DEVICE, psz_access_mode);
+    if (!p_cdio) {
+      if (psz_source) {
+	err_exit("Cannot use CD-ROM device %s. Is a CD loaded?\n",
+		 psz_source);
+      } else {
+	err_exit("%s", "Cannot find a CD-ROM with a CD loaded.\n");
+      }
+    } 
+    break;
+  case INPUT_BIN:
+    p_cdio = cdio_open_am (psz_source, DRIVER_BINCUE, psz_access_mode);
+    if (!p_cdio) {
+      if (psz_source) {
+	err_exit("%s: Error in opening CDRWin BIN/CUE image for BIN"
+		 " input %s\n", psz_source);
+      } else {
+	err_exit("%s", "Cannot find CDRWin BIN/CUE image.\n");
+      }
+    } 
+    break;
+  case INPUT_CUE:
+    p_cdio = cdio_open_cue(psz_source);
+    if (p_cdio==NULL) {
+      if (psz_source) {
+	err_exit("%s: Error in opening CDRWin BIN/CUE image for CUE"
+		 " input %s\n", psz_source);
+      } else {
+	err_exit("%s", "Cannot find CDRWin BIN/CUE image.\n");
+      }
+    } 
+    break;
+  case INPUT_NRG:
+    p_cdio = cdio_open_am (psz_source, DRIVER_NRG, psz_access_mode);
+    if (p_cdio==NULL) {
+      if (psz_source) {
+	err_exit("Error in opening Nero NRG image for input %s\n", 
+		 psz_source);
+      } else {
+	err_exit("%s", "Cannot find Nero NRG image.\n");
+      }
+    } 
+    break;
+
+  case INPUT_CDRDAO:
+    p_cdio = cdio_open_am (psz_source, DRIVER_CDRDAO, psz_access_mode);
+    if (p_cdio==NULL) {
+      if (psz_source) {
+	err_exit("Error in opening cdrdao TOC with input %s.\n", psz_source);
+      } else {
+	err_exit("%s", "Cannot find cdrdao TOC image.\n");
+      }
+    }
+    break;
+  }
+  return p_cdio;
+}
+
+
 #define DEV_PREFIX "/dev/"
 char *
 fillout_device_name(const char *device_name) 
@@ -78,6 +160,7 @@ fillout_device_name(const char *device_name)
   return strdup(device_name);
 #else
   unsigned int prefix_len = strlen(DEV_PREFIX);
+  if (!device_name) return NULL;
   if (0 == strncmp(device_name, DEV_PREFIX, prefix_len))
     return strdup(device_name);
   else {
@@ -90,11 +173,11 @@ fillout_device_name(const char *device_name)
 
 /*! Prints out SCSI-MMC drive features  */
 void 
-print_mmc_drive_features(CdIo *p_cdio)
+print_mmc_drive_features(CdIo_t *p_cdio)
 {
   
   int i_status;                  /* Result of SCSI MMC command */
-  uint8_t buf[500] = { 0, };         /* Place to hold returned data */
+  uint8_t buf[500] = { 0, };     /* Place to hold returned data */
   scsi_mmc_cdb_t cdb = {{0, }};  /* Command Descriptor Block */
   
   CDIO_MMC_SET_COMMAND(cdb.field, CDIO_MMC_GPCMD_GET_CONFIGURATION);
@@ -433,8 +516,10 @@ print_drive_capabilities(cdio_drive_read_cap_t  i_read_cap,
 
     report( stdout, _("Can set drive speed         : %s\n"), 
 	   i_misc_cap & CDIO_DRIVE_CAP_MISC_SELECT_SPEED  ? "Yes" : "No" );
+#if FIXED
     report( stdout, _("Can detect if CD changed    : %s\n"), 
 	   i_misc_cap & CDIO_DRIVE_CAP_MISC_MEDIA_CHANGED ? "Yes" : "No" );
+#endif
     report( stdout, _("Can read multiple sessions  : %s\n"), 
 	   i_misc_cap & CDIO_DRIVE_CAP_MISC_MULTI_SESSION ? "Yes" : "No" );
     report( stdout, _("Can hard reset device       : %s\n\n"), 
@@ -448,14 +533,24 @@ print_drive_capabilities(cdio_drive_read_cap_t  i_read_cap,
     report( stdout, "Uknown drive reading properties\n" );
   } else {
     report( stdout, "Reading....\n");
+    report( stdout, _("  Can read Mode 2 Form 1    : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_MODE2_FORM1 ? "Yes" : "No" );
+    report( stdout, _("  Can read Mode 2 Form 2    : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_MODE2_FORM2 ? "Yes" : "No" );
+    report( stdout, _("  Can read C2 Errors        : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_C2_ERRS     ? "Yes" : "No" );
+    report( stdout, _("  Can read IRSC             : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_ISRC        ? "Yes" : "No" );
     report( stdout, _("  Can play audio            : %s\n"), 
-	   i_read_cap & CDIO_DRIVE_CAP_READ_AUDIO      ? "Yes" : "No" );
-    report( stdout, _("  Can read  CD-R            : %s\n"), 
-	   i_read_cap & CDIO_DRIVE_CAP_READ_CD_R       ? "Yes" : "No" );
-    report( stdout, _("  Can read  CD-RW           : %s\n"), 
-	   i_read_cap & CDIO_DRIVE_CAP_READ_CD_RW      ? "Yes" : "No" );
-    report( stdout, _("  Can read  DVD-ROM         : %s\n"), 
-	   i_read_cap & CDIO_DRIVE_CAP_READ_DVD_ROM    ? "Yes" : "No" );
+	   i_read_cap & CDIO_DRIVE_CAP_READ_AUDIO       ? "Yes" : "No" );
+    report( stdout, _("  Can read CD-DA            : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_CD_DA       ? "Yes" : "No" );
+    report( stdout, _("  Can read CD-R             : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_CD_R        ? "Yes" : "No" );
+    report( stdout, _("  Can read CD-RW            : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_CD_RW       ? "Yes" : "No" );
+    report( stdout, _("  Can read DVD-ROM          : %s\n"), 
+	   i_read_cap & CDIO_DRIVE_CAP_READ_DVD_ROM     ? "Yes" : "No" );
   }
   
 
@@ -465,16 +560,18 @@ print_drive_capabilities(cdio_drive_read_cap_t  i_read_cap,
     report( stdout, "Uknown drive writing properties\n" );
   } else {
     report( stdout, "\nWriting....\n");
+    report( stdout, _("  Can write using Burn Proof: %s\n"), 
+	   i_write_cap & CDIO_DRIVE_CAP_WRITE_BURN_PROOF ? "Yes" : "No" );
     report( stdout, _("  Can write CD-RW           : %s\n"), 
-	   i_write_cap & CDIO_DRIVE_CAP_WRITE_CD_RW     ? "Yes" : "No" );
+	   i_write_cap & CDIO_DRIVE_CAP_WRITE_CD_RW      ? "Yes" : "No" );
     report( stdout, _("  Can write DVD-R           : %s\n"), 
-	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_R    ? "Yes" : "No" );
+	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_R      ? "Yes" : "No" );
     report( stdout, _("  Can write DVD-RAM         : %s\n"), 
-	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_RAM  ? "Yes" : "No" );
+	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_RAM    ? "Yes" : "No" );
     report( stdout, _("  Can write DVD-RW          : %s\n"), 
-	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_RW   ? "Yes" : "No" );
+	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_RW     ? "Yes" : "No" );
     report( stdout, _("  Can write DVD+RW          : %s\n"), 
-	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_RPW  ? "Yes" : "No" );
+	   i_write_cap & CDIO_DRIVE_CAP_WRITE_DVD_RPW    ? "Yes" : "No" );
   }
 }
 
