@@ -1,5 +1,5 @@
 #!/bin/sh
-#$Id: check_iso.sh.in,v 1.4 2004/10/28 11:13:40 rocky Exp $
+#$Id: check_iso.sh.in,v 1.5 2005/01/29 14:50:34 rocky Exp $
 
 if test -z $srcdir ; then
   srcdir=`pwd`
@@ -14,17 +14,12 @@ fi
 BASE=`basename $0 .sh`
 fname=copying
 
-opts="--quiet ${srcdir}/${fname}.iso --iso9660 "
-test_iso_info  "$opts" ${fname}.dump ${srcdir}/${fname}.right
-RC=$?
-check_result $RC 'iso-info basic test' "iso-info $opts"
-
-opts="--image ${srcdir}/${fname}.iso --extract $fname "
-test_iso_read  "$opts" ${fname} ${srcdir}/../COPYING
-RC=$?
-check_result $RC 'iso-read test 1' "iso-read $opts"
-
 if test -n "" ; then
+  opts="--quiet ${srcdir}/${fname}.iso --iso9660 "
+  test_iso_info  "$opts" ${fname}.dump ${srcdir}/${fname}.right
+  RC=$?
+  check_result $RC 'iso-info basic test' "$ISO_INFO $opts"
+
   BASE=`basename $0 .sh`
   fname=joliet
   opts="--quiet ${srcdir}/${fname}.iso --iso9660 "
@@ -38,6 +33,11 @@ if test -n "" ; then
   check_result $RC 'iso-info --no-joliet test' "$cmdline"
 fi
 
+opts="--image ${srcdir}/${fname}.iso --extract $fname "
+test_iso_read  "$opts" ${fname} ${srcdir}/../COPYING
+RC=$?
+check_result $RC 'iso-read test 1' "$ISO_READ $opts"
+
 exit $RC
 
 #;;; Local Variables: ***
