@@ -1,7 +1,7 @@
 #!/bin/sh
 #$Id: check_nrg.sh.in,v 1.11 2004/09/04 00:06:50 rocky Exp $
 
-if test -n "" ; then
+if test -n "-L/usr/local/lib -lvcdinfo -liso9660 -lcdio -lm  " ; then
   vcd_opt='--no-vcd'
 fi
 
